cardem: increase watchdog to 2 seconds

a lot of the procedures are done in ISRs, but the watchdog is only
reset in the main loop.
this causes frequent reset, particularly at the beginning were
states have to the initialized.

Change-Id: Iad364444fca9d18f9a8cf47d5e0840ccd7bac2ef
diff --git a/firmware/apps/cardem/main.c b/firmware/apps/cardem/main.c
index 7d65c7e..6cd3439 100644
--- a/firmware/apps/cardem/main.c
+++ b/firmware/apps/cardem/main.c
@@ -144,9 +144,9 @@
 	led_init();
 	led_blink(LED_RED, BLINK_3O_5F);
 
 	/* Enable watchdog for 500ms, with no window */
 	WDT_Enable(WDT, WDT_MR_WDRSTEN | WDT_MR_WDDBGHLT | WDT_MR_WDIDLEHLT |
-		   (WDT_GetPeriod(500) << 16) | WDT_GetPeriod(500));
+		   (WDT_GetPeriod(2000) << 16) | WDT_GetPeriod(2000));
 
 	PIO_InitializeInterrupts(0);
@@ -144,9 +144,9 @@
 	led_blink(LED_RED, BLINK_3O_5F);
 
-	/* Enable watchdog for 500ms, with no window */
+	/* Enable watchdog for 2000ms, with no window */
 	WDT_Enable(WDT, WDT_MR_WDRSTEN | WDT_MR_WDDBGHLT | WDT_MR_WDIDLEHLT |